namespace VirtualLabAPI.Core.FieldRepresentations {

    /// <summary>
    /// Class containing a set of harmonic fields (i.e. of instances of class ComplexAmplitude).
    /// </summary>
    [Serializable()]
    public class Latex : {

		/// <summary>
        /// Full example
		/// [SI] Calculates the sinc-function for value $x$. Sinc is defined as
		/// \f[ \operatorname{sinc}(x) = \begin{cases} 1 & x = 0 \\ \sin(x) / x & \ \ \text{else} \end{cases} \f] .
		/// </summary>
        /// <param name="sf">HarmonicFieldsSet object to copy.</param>
        /// <param name="storeDataInRAMMemory"></param>
        public void fullExample(HarmonicFieldsSet sf, bool storeDataInRAMMemory) {
                    string oldTempPath = sf.tmpCaSubFolder + sf.fieldMemberDataForHDStorage[i].FileName + ".ca2";
        }

        /// <summary>
        /// cases example
		/// [SI] Calculates the sinc-function for value $x$. Sinc is defined as
		/// \f[ (x) = \begin{cases} 1 & x = 0 \\ \sin(x) / x & \ \ \end{cases} \f] .
		/// </summary>
        /// <param name="sf">HarmonicFieldsSet object to copy.</param>
        /// <param name="storeDataInRAMMemory"></param>
        public void casesExample(HarmonicFieldsSet sf, bool storeDataInRAMMemory) {
                    string oldTempPath = sf.tmpCaSubFolder + sf.fieldMemberDataForHDStorage[i].FileName + ".ca2";
        }

		/// <summary>
        /// operatorname example
		/// [SI] Calculates the sinc-function for value $x$. Sinc is defined as
		/// \f[ \operatorname{sinc}(x) =  \f] .
		/// </summary>
        /// <param name="sf">HarmonicFieldsSet object to copy.</param>
        /// <param name="storeDataInRAMMemory"></param>
        public void operatornameExample(HarmonicFieldsSet sf, bool storeDataInRAMMemory) {
                    string oldTempPath = sf.tmpCaSubFolder + sf.fieldMemberDataForHDStorage[i].FileName + ".ca2";
        }

		/// <summary>
        /// text example
		/// [SI] Calculates the sinc-function for value $x$. Sinc is defined as
		/// \f[ 1 x = 0 \text{else} \end{cases} \f] .
		/// </summary>
        /// <param name="sf">HarmonicFieldsSet object to copy.</param>
        /// <param name="storeDataInRAMMemory"></param>
        public void textExample(HarmonicFieldsSet sf, bool storeDataInRAMMemory) {
                    string oldTempPath = sf.tmpCaSubFolder + sf.fieldMemberDataForHDStorage[i].FileName + ".ca2";
        }

		/// <summary>
        /// Inline example
		/// [SI] Calculates the sinc-function for value $x$. Sinc is defined as
		/// \f$ 1 = 0 \f$ .
		/// </summary>
        /// <param name="sf">HarmonicFieldsSet object to copy.</param>
        /// <param name="storeDataInRAMMemory"></param>
        public void inlineExample(HarmonicFieldsSet sf, bool storeDataInRAMMemory) {
                    string oldTempPath = sf.tmpCaSubFolder + sf.fieldMemberDataForHDStorage[i].FileName + ".ca2";
        }


        }                        
    }